==============
dummy-env-prep
==============

It can be hard to manage shell-script style python in a build or automated environment.  Wrap up requirements easily in one ``pip install`` and place it at the front of a Bamboo, Jenkins, or Ansible script.

This is meant as a demo.  Please fork for your own needs.

Includes
========

.. include:: requirements.txt
    :code:
